summaryrefslogtreecommitdiff
path: root/gdk
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2001-10-22 14:14:33 +0000
committerOwen Taylor <otaylor@src.gnome.org>2001-10-22 14:14:33 +0000
commit7da0a01b88f44569f3e72f49542389ecdd6e69a9 (patch)
treeaf2d20b5637706f32b086a19f86a9603c7abdcee /gdk
parent97ff064f22cdfef8abf620eb6900da6163e9b734 (diff)
downloadgdk-pixbuf-7da0a01b88f44569f3e72f49542389ecdd6e69a9.tar.gz
Don't call g_thread_init(), we don't want to link to -lgthread if we don't
Mon Oct 22 10:12:08 2001 Owen Taylor <otaylor@redhat.com> * gdk/gdk.c docs/Changes-2.0.txt (gdk_threads_init): Don't call g_thread_init(), we don't want to link to -lgthread if we don't have to.
Diffstat (limited to 'gdk')
-rw-r--r--gdk/gdk.c5
1 files changed, 2 insertions, 3 deletions
diff --git a/gdk/gdk.c b/gdk/gdk.c
index 22d13bde8..6e7c4682c 100644
--- a/gdk/gdk.c
+++ b/gdk/gdk.c
@@ -516,8 +516,7 @@ gdk_threads_leave ()
*
* Initializes GDK so that it can be used from multiple threads
* in conjunction with gdk_threads_enter() and gdk_threads_leave().
* If g_thread_init() has not yet been called, calls
* g_thread_init(NULL).
*
* This call must be made before any use of the main loop from
* GTK+; to be safe, call it before gtk_init().
@@ -526,7 +525,7 @@ void
gdk_threads_init ()
{
if (!g_thread_supported ())
- g_thread_init (NULL);
+ g_error ("g_thread_init() must be called before gdk_threads_init()");
gdk_threads_mutex = g_mutex_new ();
}
@@ -516,8 +516,7 @@ gdk_threads_leave ()
* Initializes GDK so that it can be used from multiple threads
* in conjunction with gdk_threads_enter() and gdk_threads_leave().
- * If g_thread_init() has not yet been called, calls
- * g_thread_init(NULL).
+ * g_thread_init() must be called previous to this function.
*
* This call must be made before any use of the main loop from